pecos
=====

.. automodule:: pecos



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.circuit_converters
   pecos.circuits
   pecos.classical_interpreters
   pecos.decoders
   pecos.engines
   pecos.error_models
   pecos.errors
   pecos.foreign_objects
   pecos.machines
   pecos.misc
   pecos.noise_models
   pecos.op_processors
   pecos.qeccs
   pecos.qeclib
   pecos.reps
   pecos.rslib
   pecos.simulators
   pecos.slr
   pecos.tools
   pecos.typed_list
